flutter_file_uploader library
Flutter widgets that simplify the creation and use of the
en_file_uploader library.
They include both the UI and business logic for file upload management.
Classes
- FileCard
- An agnostic file upload card widget.
- FileUploadControllerConsumer
-
Consumerwith FileUploadControllerModel - FileUploadControllerModel
- The model that manages the upload state of a file. State is composed of:
- FileUploadControllerProvider
-
ChangeNotifierProviderwith FileUploadControllerModel -
FileUploadControllerSelector<
T> -
Selectorwith FileUploadControllerModel - FileUploader
- A button that handles file uploads.
- FileUploaderConsumer
-
Consumerwith FileUploaderModel. - FileUploaderModel
- The model that manages file uploads and removals.
- FileUploaderRef
- A reference to FileUploaderModel for those who want to manage file uploads
-
FileUploaderSelector<
T> -
Selectorwith FileUploaderModel. - ProvidedFileCard
- Apply FileUploadControllerProvider and FileUploadControllerConsumer to FileCard.
Enums
- FileUploadStatus
- The various lifecycle states of the file upload process.
Typedefs
- FileUploaderBuilderCallback = Widget Function(BuildContext context, FileUploaderRef controller)
- builder, more on FileUploader
-
OnFileAdded
= Future<
IFileUploadHandler> Function(XFile file) - on file added, more on FileUploader
- OnFileRemoved = void Function(FileUploadResult file)
- on file removed, more on FileUploader
- OnFileUploaded = void Function(FileUploadResult file)
- on file uploaded, more on FileUploader
-
OnPressedAddFilesCallback
= Future<
List< Function()XFile> > - on pressed add files, more on FileUploader